==> elyra-code-viewer-extension-3.14.1.tar.gz: elyra-code-viewer-extension-3.14.1/setup.py <==
#
# Copyright 2018-2022 Elyra Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import os
import sys
from glob import glob
from jupyter_packaging import get_data_files
from setuptools import setup, find_packages

long_desc = "'The Code Viewer extension adds the ability to display a given chunk of code (string) in a transient read-only 'editor' without needing to create a file.This extension will be available in JupyterLab core in a near future release and removed from Elyra as a standalone extension.'"

here = os.path.abspath(os.path.dirname(__file__))

setup_args = dict(
    name="elyra-code-viewer-extension",
    version="3.14.1",
    url="https://github.com/elyra-ai/elyra",
    description="Elyra provides AI Centric extensions to JupyterLab",
    long_description=long_desc,
    author="Elyra Maintainers",
    license="Apache License Version 2.0",
    data_files=get_data_files([('share/jupyter/labextensions', 'build/labextensions', '**')]),
    packages=find_packages(),
    install_requires=['elyra-server==3.14.1',],
    include_package_data=True,
    classifiers=(
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ),
    entry_points={},
)

if __name__ == "__main__":
    setup(**setup_args)

==> elyra-code-viewer-extension-3.15.0rc0.tar.gz: elyra-code-viewer-extension-3.15.0rc0/setup.py <==
#
# Copyright 2018-2022 Elyra Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import os
import sys
from glob import glob
from jupyter_packaging import get_data_files
from setuptools import setup, find_packages

long_desc = "'The Code Viewer extension adds the ability to display a given chunk of code (string) in a transient read-only 'editor' without needing to create a file.This extension will be available in JupyterLab core in a near future release and removed from Elyra as a standalone extension.'"

here = os.path.abspath(os.path.dirname(__file__))

setup_args = dict(
    name="elyra-code-viewer-extension",
    version="3.15.0rc0",
    url="https://github.com/elyra-ai/elyra",
    description="Elyra provides AI Centric extensions to JupyterLab",
    long_description=long_desc,
    author="Elyra Maintainers",
    license="Apache License Version 2.0",
    data_files=get_data_files([('share/jupyter/labextensions', 'build/labextensions', '**')]),
    packages=find_packages(),
    install_requires=['elyra-server==3.15.0rc0',],
    include_package_data=True,
    classifiers=(
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ),
    entry_points={},
)

if __name__ == "__main__":
    setup(**setup_args)
